exitCode property
The exit code to use when this error is thrown.
By default, this is 1, which indicates a general error.
Implementation
final int exitCode;
The exit code to use when this error is thrown.
By default, this is 1, which indicates a general error.
final int exitCode;