ConfigError class

Error thrown when a command fails due to a configuration issue.

Inheritance

Constructors

ConfigError(String message)
Creates a new ConfigError with the given message.
const

Properties

exitCode int
The exit code to use when this error is thrown.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited