ConfigError class
Error thrown when a command fails due to a configuration issue.
- Inheritance
-
- Object
- CommandError
- ConfigError
Constructors
- ConfigError(String message)
-
Creates a new ConfigError with the given message.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited